pub struct TranscoderBuilder { /* private fields */ }Expand description
Builds a descriptor-driven transcoder from a compiled FileDescriptorSet.
Implementations
Sourceimpl TranscoderBuilder
impl TranscoderBuilder
pub fn from_descriptor_set( bytes: impl AsRef<[u8]>, channel: Channel, ) -> Result<Self, TranscodeError>
Sourcepub async fn from_reflection(channel: Channel) -> Result<Self, TranscodeError>
pub async fn from_reflection(channel: Channel) -> Result<Self, TranscodeError>
Loads all service descriptors advertised by the standard gRPC v1 reflection service.
pub fn add_binding(self, binding: HttpBinding) -> Self
Sourcepub fn load_annotated_bindings(self) -> Self
pub fn load_annotated_bindings(self) -> Self
Loads google.api.http primary and additional bindings when those extensions are present
in the descriptor set. Explicit bindings may be mixed with annotated bindings.
pub fn build(self) -> Result<Transcoder, TranscodeError>